@@ -3,7 +3,7 @@ from src import vyze
 if __name__ == "__main__":
     client = vyze.Client()
     client.login('Julian', 'goalfoev8')
-    client.use_universe('todo')
+    client.use_universe('geo3')
     obj = client.create_object(['base.object'], 'b2b981b1a7659088d3bcfe27b9e514fe', 'test_object')
     # print(obj)
     # client.delete_object(obj['id'])
